@@ -104,8 +104,6 @@ from .type_utils import (make_bool,
                          makeInt,
                          str_lower,
                          confirm_type,
-                         get_all_types,
-                         get_media_types,
                          get_all_file_types,
                          is_media_type,
                          get_bool_response,
@@ -122,6 +120,7 @@ from .type_utils import (make_bool,
                          is_any_instance,
                          break_string
                          )
+get_all_types = get_all_file_types
 from .math_utils import (convert_to_percentage,
                          exponential,
                          get_percentage,
