@@ -557,5 +557,23 @@ def get_content(*paths):
         except:
             pass
     return None
+
 def is_directory_in_paths(path,directory):
     return directory in path 
+
+def remove_directory(directory,paths=None):
+    paths = make_list_it(paths)
+    shutil.rmtree(audio_dir)
+    for path in paths:
+        remove_path(path=path)
+def remove_path(path=None):
+    if path and os.path.exists(path):
+        if os.path.isdir(path):
+            remove_directory(path)
+        else:
+            os.remove(path)
+def get_file_parts(path):
+    dirName = os.path.dirname(path)
+    baseName = os.path.basename(path)
+    fileName, ext = os.path.splitext(baseName)
+    return {"dirName": dirName, "baseName": baseName, "fileName": fileName, "ext": ext}
