@@ -3,7 +3,8 @@
 import os,fnmatch
 from pathlib import Path
 from typing import Set, List
-from abstract_utilities import make_list,get_media_exts, is_media_type  # assuming you have these
+from ...list_utils import make_list
+from ...type_utils import get_media_exts, is_media_type  # assuming you have these
 
 # ─── Configuration ────────────────────────────────────────────────────────────
 
@@ -31,7 +32,7 @@ DEFAULT_ALLOWED_EXTS: Set[str] = {
 DEFAULT_EXCLUDE_TYPES: Set[str] = {"image", "video", "audio", "presentation","spreadsheet","archive","executable"}
 # What you *never* want, regardless
 unallowed_exts: Set[str] = set(
-    get_media_exts(DEFAULT_EXLUDE_TYPES)
+    get_media_exts(DEFAULT_EXCLUDE_TYPES)
 ) | {".pyc"}
 
 DEFAULT_UNALLOWED_EXTS: Set[str] = [unallowed_ext for unallowed_ext in list(unallowed_exts) if unallowed_ext not in list(DEFAULT_ALLOWED_EXTS)]
